/*
** ############################################################################
**
**		Filename  : DEMOACEX_touchpad.c
**		Compiler  : Freescale CodeWarrior C Compiler
**		Date      : March 2008
**
**#############################################################################     
**
**    E-Field Touchpad Demo code for the AC family of MCUs for use on DEMOAC  
**		board with the DEMOACEX expansion board, both from Axiom Manufacturing.  
**    This code may be freely distributed or modified.   
**		No functionality or usability is implied or guaranteed.
**
**		Visit us at      http://www.axman.com
**
** ############################################################################
*/

#include <hidef.h>            // for EnableInterrupts macro 
#include "derivative.h"       // include peripheral declarations 
#include "S08_to_CFV1.h"      /* include S08 to Coldfire V1 declarations */
#include "DEMOACEX_touchpad.h"      /* include S08 to Coldfire V1 declarations */

// Declare functions PeriphInit which is defined in S08_to_CFV1.c
void PeriphInit(void);

void initPort(){
   
   // init LED drive registers
   PTAD = 0xFF;               // init Port A
   PTED = 0xFF;               // init Port E
   PTFD = 0xFF;               // init Port F
   
   PTADD = 0xFD;              // PTAD[7:2, 0] output
   PTEDD = 0xFC;              // PTED[7:2] output
   PTFDD = 0x33;              // PTFD[5:4, 1;0] output

// init EF sensor select 
   PTCD = 0x10;               // init Port C
   PTCDD = 0x17;              // PTCD[2:0] output
} // initPort

void initADC(){
   ADC1SC1 = 0x1F;            // single convert, ADC disabled
   ADC1SC2 = 0x00;            // SW trigger, compare function disabled
   ADC1CFG = 0x03;            // Asynch clk selected, input clock / 1, 8 bit mode
   APCTL2 = 0x09;             // enable EF_LEVEL input (ADP1P11)
} // initADC

byte MeasADC(byte chnl){
 byte i;
 
  adc_tot=0;
  // start ADC with continuous conversions
  ADC1SC1 = (byte)((chnl & 0x1F) | ADC1SC1_ADCO_MASK | ADC1SC1_AIEN_MASK);
  // take 8 readings and total
  for(i=0; i<8; i++){
    _Wait;
  } // for
  ADC1SC1 = 0x1F;    // turn ADC off
  // average the 8 readings and return value
  return (byte)(adc_tot>>3);
} // MeasADC

void main(void) {
unsigned char n, LED_1= led_on, LED_0 = led_off, rotator;        

	EnableInterrupts;          // enable interrupts
   
  PeriphInit();
	initPort();                // init GPIO ports
	initADC();                 // initialize ADC using AD1P11

  for (;;){
    sensitivity = MeasADC(8); // read POT to set sensitivity of efield

    for (n=1; n<8; n++){
	  	PTCD = EF_SEL[n];    // select EF electrode
	  	SRTISC = 0x52;       // setup RTI for 32 msec timeout
	  	_Wait;
	  	Electrode[n] = MeasADC(11);
    } // for (n=1;
    
		if(Electrode[1]<sensitivity)
		  led1=led_on;
		else
			led1=led_off;
		
		if(Electrode[2]<sensitivity)
		  led2=led_on;
		else
			led2=led_off;
		
		if(Electrode[3]<sensitivity)
		  led3=led_on;
		else
			led3=led_off;
		
		if(Electrode[7]<sensitivity){
		  LED_1=!LED_1;
			LED_0=!LED_0;   
		}
		
		rotator = 0;
		if (Electrode[4]<sensitivity)
		  rotator |= 0b0001;
		if (Electrode[5]<sensitivity)
		  rotator |= 0b0010;
		if (Electrode[6]<sensitivity)
		  rotator |= 0b0100;

		switch (rotator){
		  case 0:	led10=LED_0; led9=LED_0; led8=LED_0; led7=LED_0; led6=LED_0; led5=LED_0; break;
		  case 1:	led10=LED_0; led9=LED_0; led8=LED_1; led7=LED_0; led6=LED_0; led5=LED_0; break;
		  case 2:	led10=LED_1; led9=LED_0; led8=LED_0; led7=LED_0; led6=LED_0; led5=LED_0; break;
		  case 3:	led10=LED_0; led9=LED_1; led8=LED_0; led7=LED_0; led6=LED_0; led5=LED_0; break;
		  case 4:	led10=LED_0; led9=LED_0; led8=LED_0; led7=LED_0; led6=LED_1; led5=LED_1; break;
		  case 5:	led10=LED_0; led9=LED_0; led8=LED_0; led7=LED_1; led6=LED_0; led5=LED_0; break;
		  case 6:	led10=LED_1; led9=LED_0; led8=LED_0; led7=LED_0; led6=LED_1; led5=LED_1; break;
		  case 7:	led10=LED_0; led9=LED_0; led8=LED_0; led7=LED_0; led6=LED_0; led5=LED_0; break;
		  default: led10=LED_0; led9=LED_1; led8=LED_0; led7=LED_1; led6=LED_0; led5=LED_0;
		} //switch
		    
  } // for (;;)
} // main

/************* Interrupts ****************************************************/
interrupt VectorNumber_Vrti void RTI_ISR(void){
  SRTISC = SRTISC_RTIACK_MASK; // clear RTIF and disable RTI
}

interrupt VectorNumber_Vadc1 void ADC1_ISR(void){
  adc_tot += ADC1RL;
}

/************* Function Prototypes *******************************************/

void initADC(void);           // init ADC module
void initPort(void);          // init GPIO Ports
