/*
** ############################################################################
**
**		Filename  : S08_to_CFV1.c
**		Compiler  : Freescale CodeWarrior C Compiler
**		Date      : March 2008
**
**#############################################################################     
**
**    S08 to CFV1 compatability code for the Flexis AC family. 
**    This code may be freely distributed or modified. No functionality or 
**    usability is implied or guaranteed.
**
**
** ############################################################################
*/

#include <hidef.h>                        /* for EnableInterrupts macro */
#include "derivative.h"                   /* include peripheral declarations */
#include "S08_to_CFV1.h"                  /* include S08 to Coldfire V1 declarations */


#ifdef _MCF51AC256A_H
  
 void BUS_CLK_SETUP(void){
  
  /* Configure MCG to run in PEE Mode */
  /* 20MHz bus clock from a 4MHz external crystal */
  
  /* set up external oscillator */
  MCGC2 = 0x26; /* RANGE = 1; HGO = 0; ERCLKEN=1; EREFS = 1; BDIV = 00 (/1); */
   
  while (!MCGSC_OSCINIT){}/* wait for oscillator to initialize */
  
  /* Configure MCGC3 to access the proper RDIV values */
  MCGC3 = 0x10; /* DIV32 = 1; */
    
  /* Select Clock Mode and Reference Divider */
  MCGC1 = 0x90; /* CLKS = 10; RDIV = 2 (/4, /128 with DIV32=1); IREFS = 0; */

  while (MCGSC_IREFST){} /* wait for Reference Status bit to update */
  
  /* Wait for clock status bits to update */
  while (MCGSC_CLKST != 0b10){}        
  
  /* Configure MCGC3 to select PLL and VDIV */
  MCGC3 = 0x5A; /* PLLS =1; DIV32 = 1; VDIV = 1010 (x40) */
  
  while (!MCGSC_PLLST){} /* wait for PLL status bit to update */
  
  while (!MCGSC_LOCK){} /* Wait for LOCK bit to set */

  /* Now running PBE Mode */
  
  /* Transition into PEE */
  MCGC1 = 0x10; /* CLKS = 00; RDIV = 2 (/4 with PLLS=1); IREFS = 0; */

  /* Wait for clock status bits to update */
  while (MCGSC_CLKST != 0b11){};           

  /* Now running PEE Mode */
 } //end of MCG_PEE_20M(void) 

#else

 void BUS_CLK_SETUP(void){
  
  /* Configure ICG to run in FEE Mode */
  /* 20MHz bus clock from a 4MHz external crystal */
  
  /* set up external oscillator */
  ICGC1 = 0x78; /* HGO = 0; RANGE = 1; REFS = 1; CLKS=11; */
  ICGC2 = 0x30; /* MFD = x10; RFD = /1; interrupt on LOL and LOC */

  /* Wait until ICG enters the chosen clock mode */
  while (ICGS1_CLKST != ICGC1_CLKS);
   
  /* Wait for LOCK bit to set */
  while (!ICGS1_LOCK);

 } //end of ICG_FEE_20M(void) 
 
#endif 
  
///////////////////////////////////////////////////////////////////////////////
// PeriphInit
// ----------------------------------------------------------------------------
// Initializes various registers and peripherals
///////////////////////////////////////////////////////////////////////////////
void PeriphInit(void){

  SOPT = 0x20;                     // disable COP, enable STOP
  
  
  BUS_CLK_SETUP();                   // fBUS 20 MHz
  
  
  PTAPE = 0xFF;                    // Enable Port pullups
  PTBPE = 0xFF; 
  PTCPE = 0xFF; 
  PTDPE = 0xFF; 
  PTEPE = 0xFF; 
  PTFPE = 0xFF; 
  PTGPE = 0xFF; 
  
#ifdef _MCF51AC256A_H
  PTHPE = 0xFF;                           // Enable PORT H Internal Pullups
  PTJPE = 0xFF;                           // Enable PORT J Internal Pullups
#endif  

#ifdef _MC9S08AC128_H
  PTHPE = 0xFF;                           // Enable PORT H Internal Pullups
  PTJPE = 0xFF;                           // Enable PORT J Internal Pullups
#endif  
  
  
  APCTL2_ADPC9 = 1;                 // Enable accelerometer 'X' analog input
  APCTL1_ADPC2 = 1;                 // Enable accelerometer 'Y' analog input
  APCTL1_ADPC3 = 1;                 // Enable accelerometer 'Z' analog input
  ADC1CFG = 0x44;                   // Configures ADC peripheral (ADC clock = 6.25MHz)
                                    // Bus clock as clock source, 12-bit conversion and divisor=4
} // end of PeriphInit
  
