#include <hidef.h>            // for EnableInterrupts macro 
#include "derivative.h"       // include peripheral declarations 


#define loff   0xFF           // LEDs off
#define led1   0xFE           // LED1 on
#define led2   0xFD           // LED2 on
#define led3   0xEF           // LED3 on
#define led4   0xDF           // LED4 on

#define led5   0xFB          // LED5 on
#define led6   0xF7          // LED6 on
#define led7   0xEF          // LED7 on
#define led8   0xDF          // LED8 on
#define led9   0xBF          // LED9 on
#define led10  0x7F          // LED10 on

#define led11  0xFB          // LED11 on
#define led12  0xF7          // LED12 on
#define led13  0xEF          // LED13 on
#define led14  0xDF          // LED14 on
#define led15  0xBF          // LED15 on
#define led16  0x7F          // LED16 on

unsigned char LED[] = {led1, led2, led3, led4, led5, led6,
                       led7, led8, led9, led10, led11, led12,
                       led13, led14, led15, led16};
unsigned char EF_SEL[] = {0, 1, 2, 3, 4, 5, 6, 7};
unsigned char ADC_RL[] = {0x00, 0x33, 0x66, 0x99, 0xCC, 0xFF};

unsigned char sw_press = 0x00;   // indicates PBSW pressed


void dly(){
   // delay loop
   int loop1, loop2;          // temp variables

   for(loop1=0x02; loop1>0; loop1--) {		// outer loop
      for(loop2=0xFFFF; loop2>0; loop2--){
      ;}                      // dec inner loop
   }
}

void initPort(){
   PTGPE = 0x0F;              // PTGD pull ups enabled
   KBISC = KBISC_KBACK_MASK;  // clear pending keyboard interrupt
//   KBIES = 0x00;              // falling edge detect
   KBIPE = 0x0F;              // KBI[3:0] enabled on pin
   KBISC = KBISC_KBIE_MASK;   // enable kyeboard interrupt, edges only
   
   
   // init LED drive registers
   PTAD = 0xFF;               // init Port A
   PTED = 0xFF;               // init Port E
   PTFD = 0xFF;               // init Port F
   
   PTADD = 0xFD;              // PTAD[7:2, 0] output
   PTEDD = 0xFC;              // PTED[7:2] output
   PTFDD = 0x33;              // PTFD[5:4, 1;0] output

// init EF sensor select 
   PTCD = 0x00;               // init Port C
   PTCDD = 0x17;                // PTCD[2:0] output
}

void initMCG(){
   MCGC2 = 0x26;              // MCG output / 1, en hi range ext osc
   MCGC1 = 0x3C;              // ext clk / 128, int ref selected
   MCGC1 = 0x38;              // sel ext ref input
   MCGC4 = 0x02;              // FLL x 1536 output

}

void initFTM1(){
   FTM1MODH = 0x00;           // mod count high
   FTM1MODL = 0x02;           // mod count low
   FTM1SC = 0x08;             // clk input = system clock
   FTM1C0SC = 0x14;				// en FTM1C0, toggle output on compare
}

void initFTM2(){
   FTM2MODH = 0x00;           // mod count high
   FTM2MODL = 0x03;           // mod count low
   FTM2SC = 0x08;             // clk input = system clock
   FTM2C0SC = 0x14;				// en FTM2C0, toggle output on compare
}

void initADC(){
   ADC1SC1 = 0x3F;            // continuous convert, ADC disabled
   ADC1SC2 = 0x00;            // SW trigger, compare function disabled
   ADC1CFG = 0x00;            // bus clk selected, input clock / 1, 8 bit mode
   APCTL2 = 0x08;             // enable EF_LEVEL input (ADP1P11)
   ADC1SC1 = 0x2B;            // enable AD1P11 input
}

void pot_test(){
   unsigned char n;           // temp var
   for(n=0; n<5; ++n){
      if ((ADC1RL > ADC_RL[n]) &(ADC1RL < ADC_RL[n+1])) {
         PTFD = LED[n];       // turn on LED
      }
   }
}

void main(void) {

	SOPT = !SOPT_COPE_MASK;    // disable COP
	EnableInterrupts;          // enable interrupts
   
	initPort();                // init GPIO ports
	initFTM1();                // initialize FTM1 module
	initFTM2();                // initialize FTM2 module
	initMCG();                 // init MCG module
	initADC();                 // initialize ADC using AD1P11

   PTAD_PTAD2 = 0;				// enable CAN XCVR
   
   for (;;){
      unsigned char n;        // temp var
      
      
      for (n=1; n<8; n++){
			PTAD = 0xF8;				// all LEDs off
			PTED = 0xFF;			
			PTCD = EF_SEL[n];    // select EF electrode
			dly();					// wait
			PTAD_PTAD0 ^= 1;		// toggle PTAD0 - CAN Test
			if(ADC1RL < 0x66)    // if selected sensor is touched
				if(n > 3){       // if electrode 4 - 7 selected
					PTAD = LED[n+8];  // turn on selected PTA LED
				} else {
					PTED = LED[n+6];  // turn on selected PTE LED
				}
			dly();                  // wait
		}
	}
}

/************* Interrupts ****************************************************/
interrupt VectorNumber_Vkeyboard void KBI_ISR(void){
   
   KBISC = !KBISC_KBIE_MASK;  // disable keyboard interrupt
   KBISC = KBISC_KBACK_MASK;  // clear pending interrupt
   sw_press = 0x01;           // get value of sw press
   KBISC = KBISC_KBIE_MASK;   // enable keyboard interrupt
}

/************* Function Prototypes *******************************************/

void dly(void);               // loop delay routine
void initFTM1(void);          // initialize FTM1 module
void initFTM2(void);          // initialize FTM2 module
void initADC(void);           // init ADC module
void initPort(void);          // init GPIO Ports
void initMCG(void);           // init MCG module
void pot_test();              // test POT input